import React from 'react';
import SvgIcon from '../../../components/SvgIcon';

export default function RequestDetailSlideOver({
    show,
    onClose,
    request,
    onApprove,
    onReject,
    processingId,
    approveRejectStatus,
    isApproving,
}) {
    if (!request) return null;

    // 获取申请人信息
    const applicantName = request.applicant?.name || request.applicant?.username || '未知用户';
    const applicantDept = request.applicant?.department || '未分配部门';
    const applicantInitial = applicantName.charAt(0);
    const knowledgeBaseName = request.knowledge_base?.name || '未知知识库';
    const knowledgeBaseId = request.knowledge_base?.id || '';
    const knowledgeBaseType = request.knowledge_base?.type || '';

    return (
        <>
            <div className={`slide-over-backdrop ${show ? 'show' : ''}`} onClick={onClose}></div>
            <div className={`slide-over ${show ? 'show' : ''}`}>
                <div className='slide-over-content'>
                    <div className='slide-over-header'>
                        <h5 className='mb-0'>申请详情</h5>
                        <button type='button' className='btn-close' onClick={onClose}></button>
                    </div>
                    <div className='slide-over-body'>
                        <div className='mb-4'>
                            <h6 className='text-muted mb-2'>申请人信息</h6>
                            <div className='d-flex align-items-center mb-3'>
                                <div className='avatar-placeholder me-3 bg-dark'>{applicantInitial}</div>
                                <div>
                                    <h5 className='mb-1'>{applicantName}</h5>
                                    <div className='text-muted'>{applicantDept}</div>
                                </div>
                            </div>
                        </div>

                        <div className='mb-4'>
                            <h6 className='text-muted mb-2'>知识库信息</h6>
                            <p className='mb-1'>
                                <strong>名称：</strong> {knowledgeBaseName}
                            </p>
                            <p className='mb-1'>
                                <strong>ID：</strong> {knowledgeBaseId}
                            </p>
                            {knowledgeBaseType && (
                                <p className='mb-1'>
                                    <strong>类型：</strong> {knowledgeBaseType}
                                </p>
                            )}
                        </div>

                        <div className='mb-4'>
                            <h6 className='text-muted mb-2'>申请权限</h6>
                            <div className='d-flex flex-wrap gap-2 mb-3'>
                                {request.permissions?.can_read && !request.permissions?.can_edit && (
                                    <span className='badge bg-warning-subtle text-warning d-flex align-items-center gap-1'>
                                        <SvgIcon className={'eye'} />
                                        只读
                                    </span>
                                )}
                                {request.permissions?.can_edit && (
                                    <span className='badge bg-success-subtle text-success d-flex align-items-center gap-1'>
                                        <SvgIcon className={'pencil'} />
                                        编辑
                                    </span>
                                )}
                                {request.permissions?.can_delete && (
                                    <span className='badge bg-danger-subtle text-danger d-flex align-items-center gap-1'>
                                        <SvgIcon className={'trash'} />
                                        删除
                                    </span>
                                )}
                            </div>
                        </div>

                        <div className='mb-4'>
                            <h6 className='text-muted mb-2'>申请时间</h6>
                            <p className='mb-1'>{new Date(request.created_at || Date.now()).toLocaleString()}</p>
                        </div>

                        {request.expires_at && (
                            <div className='mb-4'>
                                <h6 className='text-muted mb-2'>到期时间</h6>
                                <p className='mb-1'>{new Date(request.expires_at).toLocaleString()}</p>
                            </div>
                        )}

                        {request.status && (
                            <div className='mb-4'>
                                <h6 className='text-muted mb-2'>申请状态</h6>
                                <p className='mb-1'>
                                    {request.status === 'pending' ? (
                                        <span className='badge bg-warning'>待处理</span>
                                    ) : request.status === 'approved' ? (
                                        <span className='badge bg-success'>已批准</span>
                                    ) : (
                                        <span className='badge bg-danger'>已拒绝</span>
                                    )}
                                </p>
                            </div>
                        )}

                        {request.approver && (
                            <div className='mb-4'>
                                <h6 className='text-muted mb-2'>审批人</h6>
                                <p className='mb-1'>
                                    {request.approver.name || request.approver.username} ({request.approver.department || '未分配部门'})
                                </p>
                            </div>
                        )}

                        {request.response_message && (
                            <div className='mb-4'>
                                <h6 className='text-muted mb-2'>审批意见</h6>
                                <div className='p-3 bg-light rounded'>{request.response_message}</div>
                            </div>
                        )}

                        <div className='mb-4'>
                            <h6 className='text-muted mb-2'>申请理由</h6>
                            <div className='p-3 bg-light rounded'>
                                {request.reason || '无申请理由'}
                            </div>
                        </div>
                    </div>
                    {request.status === 'pending' && (
                        <div className='slide-over-footer'>
                            <button
                                className='btn btn-outline-danger me-2'
                                onClick={() => onReject(request.id)}
                                disabled={processingId === request.id && approveRejectStatus === 'loading'}
                            >
                                {processingId === request.id && approveRejectStatus === 'loading' && !isApproving ? (
                                    <>
                                        <span
                                            className='spinner-border spinner-border-sm me-1'
                                            role='status'
                                            aria-hidden='true'
                                        ></span>
                                        处理中...
                                    </>
                                ) : (
                                    <>拒绝</>
                                )}
                            </button>
                            <button
                                className='btn btn-outline-success'
                                onClick={() => onApprove(request.id)}
                                disabled={processingId === request.id && approveRejectStatus === 'loading'}
                            >
                                {processingId === request.id && approveRejectStatus === 'loading' && isApproving ? (
                                    <>
                                        <span
                                            className='spinner-border spinner-border-sm me-1'
                                            role='status'
                                            aria-hidden='true'
                                        ></span>
                                        处理中...
                                    </>
                                ) : (
                                    <>批准</>
                                )}
                            </button>
                        </div>
                    )}
                </div>
            </div>
        </>
    );
}
