import { createAsyncThunk } from '@reduxjs/toolkit';
import { get, post } from '../../services/api';
import { showNotification } from '../notification.slice';
import { logout } from './auth.slice';
import CryptoJS from 'crypto-js';

const secretKey = import.meta.env.VITE_SECRETKEY;

export const loginThunk = createAsyncThunk(
    'auth/login',
    async ({ username, password }, { rejectWithValue, dispatch }) => {
        try {
            const { message, data, code } = await post('/auth/login/', { username, password });
            console.log('code', code);

            if (code !== 200) {
                throw new Error(message || 'Something went wrong');
            }
            if (!data) {
                throw new Error(message || 'Something went wrong');
            }
            const { token } = data;
            // encrypt token
            const encryptedToken = CryptoJS.AES.encrypt(token, secretKey).toString();
            sessionStorage.setItem('token', encryptedToken);

            return data;
        } catch (error) {
            const errorMessage = error.response?.data?.message || 'Something went wrong';
            console.log(errorMessage);
            dispatch(
                showNotification({
                    message: errorMessage,
                    type: 'danger',
                })
            );
            return rejectWithValue(errorMessage);
        }
    }
);

export const signupThunk = createAsyncThunk('auth/signup', async (userData, { rejectWithValue, dispatch }) => {
    try {
        // 使用新的注册 API
        const response = await post('/auth/register/', userData);
        console.log('注册返回数据:', response);

        // 处理新的返回格式
        if (response && response.code === 200) {
            // // 将 token 加密存储到 sessionStorage
            // const { token } = response.data;
            // if (token) {
            //     const encryptedToken = CryptoJS.AES.encrypt(token, secretKey).toString();
            //     sessionStorage.setItem('token', encryptedToken);
            // }

            // 显示注册成功通知
            dispatch(
                showNotification({
                    message: '注册成功',
                    type: 'success',
                })
            );
            return response.data;
        }

        return rejectWithValue(response.message || '注册失败');
    } catch (error) {
        const errorMessage = error.response?.data?.message || '注册失败，请稍后重试';
        dispatch(
            showNotification({
                message: errorMessage,
                type: 'danger',
            })
        );
        return rejectWithValue(errorMessage);
    }
});

export const checkAuthThunk = createAsyncThunk('auth/verify', async (_, { rejectWithValue, dispatch }) => {
    try {
        const { data, message } = await post('/auth/verify-token/');
        const { user } = data;
        if (!user) {
            dispatch(logout());
            throw new Error(message || 'No token found');
        }
        return user;
    } catch (error) {
        dispatch(logout());
        return rejectWithValue(error.response?.data || 'Token verification failed');
    }
});

// Async thunk for logging out
export const logoutThunk = createAsyncThunk('auth/logout', async (_, { rejectWithValue, dispatch }) => {
    try {
        // Send the logout request to the server (this assumes your server clears any session-related info)
        await post('/auth/logout/');
        dispatch(logout());
    } catch (error) {
        const errorMessage = error.response?.data?.message || 'Log out failed';
        dispatch(
            showNotification({
                message: errorMessage,
                type: 'danger',
            })
        );
        return rejectWithValue(errorMessage);
    }
});
